using System;
using System.Collections.Generic;
using System.Text;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Grouping;
using System.Runtime.Serialization;
using System.Drawing;

namespace GGC_Sample1
{

    [Serializable]
    public class CustomCellModel : GridTextBoxCellModel
    {
        protected CustomCellModel(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
            
        }

        public CustomCellModel(GridModel grid)
            : base(grid)
        {
        }

        public override GridCellRendererBase CreateRenderer(GridControlBase control)
        {
            return new CustomCellRenderer(control, this);
        }
    }

    public class CustomCellRenderer : GridTextBoxCellRenderer
    {
        #region Data Members

        GridCellModelBase m_Model;
        Size m_ButtonBarSize = Size.Empty;


        #endregion // Data Members

        public CustomCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
            : base(grid, cellModel)
        {
            m_Model = cellModel;
        }

        protected override bool OnSaveChanges()
        {
            ICustomObject typedValue = this.ControlValue as ICustomObject;
            if (typedValue != null)
            {
                typedValue.DoubleValue = Double.Parse(TextBox.Text);
                ControlValue = typedValue;
                return true;
            }
            else
            {
                typedValue = new CustomObject();
                typedValue.DoubleValue = Double.Parse(TextBox.Text);
                GridTableControl tc = this.Grid as GridTableControl;
                GridTableCellStyleInfo info = this.Grid.Model[RowIndex, ColIndex] as GridTableCellStyleInfo;
                if (tc != null && info.TableCellIdentity.DisplayElement.Kind == Syncfusion.Grouping.DisplayElementKind.AddNewRecord)
                {
                    tc.Table.AddNew();
                }
                this.Grid.Model[RowIndex, ColIndex].CellValue = typedValue;
                CurrentCell.IsModified = false;
                return true;
            }

        }
    }


}
